@@ -205,6 +205,51 @@ class XItem(XEntity):
 
     Description = property(get_description, set_description)
 
+
+    def get_purchase_details(self):
+        """
+        Returns the purchase details.
+        """
+        return self.get("PurchaseDetails")
+
+    def set_purchase_details(self, purchase_details):
+        """
+        Sets the purchase details.
+
+        TODO: Provide a more generalized representation.
+        #   <PurchaseDetails>
+        #     <UnitPrice>42.00</UnitPrice>
+        #     <AccountCode>300</AccountCode>
+        #     <TaxType>NONE</TaxType>
+        #   </PurchaseDetails>
+        """
+        self["PurchaseDetails"] = purchase_details
+
+    PurchaseDetails = property(get_purchase_details, set_purchase_details)
+
+
+    def get_sales_details(self):
+        """
+        Returns the sales details.
+        """
+        return self.get("SalesDetails")
+
+    def set_sales_details(self, sales_details):
+        """
+        Sets the sales details.
+
+        TODO: Provide a more generalized representation.
+        #   <SalesDetails>
+        #     <UnitPrice>42.00</UnitPrice>
+        #     <AccountCode>300</AccountCode>
+        #     <TaxType>NONE</TaxType>
+        #   </SalesDetails>
+        """
+        self["SalesDetails"] = sales_details
+
+    SalesDetails = property(get_sales_details, set_sales_details)
+
+
     def to_xml(self):
         """
         Provides a json representation of the invoice.
@@ -800,8 +845,8 @@ class XInvoice(XEntity):
         if not response["Response"].has_key("Invoices"):
             return retval
 
-        for item in response["Response"]["Invoices"]["Invoice"]:
-            print item
+        #for item in response["Response"]["Invoices"]["Invoice"]:
+            #print item
             # account = XItem(item["Code"],
             #                 item["Description"],
             #                 item["PurchaseDetails"]["UnitPrice"] if item.has_key("PurchaseDetails") else None,
@@ -818,21 +863,11 @@ class XInvoice(XEntity):
         """
         Updates or Creates a new invoice on the XERO.
         """
-        print invoice.to_xml()
-
         # Post the item:
         response = client.post("Invoice", invoice.to_xml())
 
         return response["Response"]
 
-        # Iterate over the accounts:
-        #xitem = XItem()
-        #xitem.Code = response["Response"]["Items"]["Item"]["Code"]
-        #xitem.Description = response["Response"]["Items"]["Item"]["Description"]
-
-        # Done, return the xitem:
-        #return xitem
-
 
 class XBrandingTheme(XEntity):
     """
